@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.20 2003/12/30 21:53:28 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.22 2004/01/11 02:02:19 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -37,6 +37,7 @@
 #include "paned_notebook.h"
 #include "threadlist_view.h"
 #include "icon_label.h"
+#include "bbs_thread_view.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -45,7 +46,7 @@ extern "C" {
 
 typedef enum
 {
-  BBS_THREAD_FAVORITE	= 1 << 0,
+  BBS_THREAD_MARKED	= 1 << 0,
   BBS_THREAD_HIDDEN	= 1 << 1,
   BBS_THREAD_NEW	= 1 << 2,
 } ThreadlistEntryFlags;
@@ -84,6 +85,12 @@ typedef struct _BBSThreadGUIInfo
   /* ɽɽ֤դޡ */
   GtkTextMark *next_mark;
 
+  /* ɽ֤᤹Υꥹ(Ƭ˺Ƕɽoffset) */
+  GSList *backward_history;
+
+  /* ɽ֤ʤ뤿Υꥹ(Ƭ˺Ƕɽoffset) */
+  GSList *forward_history;
+
   /* ɸɽ֤ޤǳμ¤()뤵뤿idleؿ */
   guint scroller_id;
 
@@ -138,6 +145,9 @@ GtkWidget *open_bbs_thread(OchushaApplication *application,
 
 void refresh_thread(OchushaApplication *application, GtkWidget *widget,
 		    OchushaBBSThread *thread, IconLabel *tab_label);
+
+void save_thread_view_position(GtkWidget *view, OchushaBBSThread *thread);
+
 void go_to_the_first_response(GtkWidget *widget, OchushaBBSThread *thread);
 void go_to_the_last_response(GtkWidget *widget, OchushaBBSThread *thread);
 void jump_to_bookmark(GtkWidget *widget, OchushaBBSThread *thread);
