@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.37 2004/01/11 02:02:19 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.38 2004/01/13 14:54:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -515,7 +515,7 @@ bbs_thread_view_finalize(GObject *object)
 
   if (view->text_buffer != NULL)
     {
-      g_object_unref(G_OBJECT(view->text_buffer));
+      OCHU_OBJECT_UNREF(G_OBJECT(view->text_buffer));
       view->text_buffer = NULL;
     }
   if (view->tags != NULL)
