@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.71 2004/01/13 02:41:52 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.73 2004/01/13 15:23:27 fuyu Exp $
  */
 
 #include "config.h"
@@ -247,11 +247,13 @@ ensure_my_folder(OchushaApplication *application)
 				       application->favorites);
     }
 
+#if 0
   if (application->favorites->thread_list == NULL)
     ochusha_bulletin_board_read_threadlist_xml(application->favorites,
 					       &application->config,
 					       application->session_subdir,
 					       FALSE);
+#endif
 
   if (application->all_threads == NULL)
     {
@@ -266,11 +268,13 @@ ensure_my_folder(OchushaApplication *application)
 				       application->all_threads);
     }
 
+#if 0
   if (application->all_threads->thread_list == NULL)
     ochusha_bulletin_board_read_threadlist_xml(application->all_threads,
 					       &application->config,
 					       application->session_subdir,
 					       FALSE);
+#endif
 }
 
 
@@ -1609,7 +1613,7 @@ uri_dropped_cb(BoardlistView *view, OchushaBoardCategory *category,
 							 dropped_board->base_url);
 	  if (tmp_board != NULL)
 	    {
-	      g_object_ref(G_OBJECT(tmp_board));
+	      OCHU_OBJECT_REF(G_OBJECT(tmp_board));
 	      ochusha_board_category_remove_board(category, tmp_board);
 	      boardlist_view_remove_board(view, category, tmp_board);
 	    }
@@ -1617,7 +1621,7 @@ uri_dropped_cb(BoardlistView *view, OchushaBoardCategory *category,
 	  ochusha_board_category_add_board(category, dropped_board);
 
 	  if (tmp_board != NULL)
-	    g_object_unref(G_OBJECT(tmp_board));
+	    OCHU_OBJECT_UNREF(G_OBJECT(tmp_board));
 	  
 	  boardlist_view_add_board(view, dropped_board,
 				   category, board);
