@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.29 2004/01/13 02:41:52 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.30 2004/01/13 14:54:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -942,7 +942,11 @@ boardlist_view_finalize(GObject *object)
 #if DEBUG_WIDGET_MOST
   fprintf(stderr, "boardlist_view_finalize\n");
 #endif
-  g_object_unref(G_OBJECT(view->model));
+  if (view->model != NULL)
+    {
+      OCHU_OBJECT_UNREF(G_OBJECT(view->model));
+      view->model = NULL;
+    }
 
   if (G_OBJECT_CLASS(parent_class)->finalize)
     (*G_OBJECT_CLASS(parent_class)->finalize)(object);
@@ -1874,7 +1878,7 @@ boardlist_view_open(BoardlistView *view, GSList *category_list,
   gtk_tree_view_set_model(&view->view, GTK_TREE_MODEL(store));
 
   if (view->model != NULL)
-    g_object_unref(G_OBJECT(view->model));
+    OCHU_OBJECT_UNREF(G_OBJECT(view->model));
   view->model = GTK_TREE_MODEL(store);
 }
 
