@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.115 2004/01/13 02:43:30 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.116 2004/01/13 14:54:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -239,7 +239,7 @@ prepare_board_ui_initialization(OchushaApplication *application)
   if (engine->is_busy)
     {
       fprintf(stderr, "Couldn't initialize scheme engine...disabled.\n");
-      g_object_unref(G_OBJECT(engine));
+      OCHU_OBJECT_UNREF(G_OBJECT(engine));
       engine = NULL;
     }
   else
@@ -370,10 +370,13 @@ threadlist_read_thread_element_cb(OchushaBulletinBoard *board,
 
   info->view_ignored = ochusha_utils_get_attribute_int(hash_table,
 						       "view_ignored");
-  info->last_name = ochusha_utils_get_attribute_string(hash_table,
-						       "last_name");
-  info->last_mail = ochusha_utils_get_attribute_string(hash_table,
-						       "last_mail");
+  if (info->last_name == NULL)
+    info->last_name = ochusha_utils_get_attribute_string(hash_table,
+							 "last_name");
+
+  if (info->last_mail == NULL)
+    info->last_mail = ochusha_utils_get_attribute_string(hash_table,
+							 "last_mail");
   if ((info->view_flags & BBS_THREAD_HIDDEN) != 0)
     ochusha_bbs_thread_set_number_of_responses_read(thread, 0);
 
@@ -385,19 +388,25 @@ threadlist_read_thread_element_cb(OchushaBulletinBoard *board,
 
   info->thread_local_a_bone
     = ochusha_utils_get_attribute_boolean(hash_table, "thread_local_a_bone");
+
   info->a_bone_by_name
     = ochusha_utils_get_attribute_boolean(hash_table, "a_bone_by_name");
-  info->a_bone_by_name_pattern
-    = ochusha_utils_get_attribute_string(hash_table, "a_bone_by_name_pattern");
+  if (info->a_bone_by_name_pattern == NULL)
+    info->a_bone_by_name_pattern
+      = ochusha_utils_get_attribute_string(hash_table,
+					   "a_bone_by_name_pattern");
   info->a_bone_by_id
     = ochusha_utils_get_attribute_boolean(hash_table, "a_bone_by_id");
-  info->a_bone_by_id_pattern
-    = ochusha_utils_get_attribute_string(hash_table, "a_bone_by_id_pattern");
+  if (info->a_bone_by_id_pattern == NULL)
+    info->a_bone_by_id_pattern
+      = ochusha_utils_get_attribute_string(hash_table, "a_bone_by_id_pattern");
+
   info->a_bone_by_content
     = ochusha_utils_get_attribute_boolean(hash_table, "a_bone_by_content");
-  info->a_bone_by_content_pattern
-    = ochusha_utils_get_attribute_string(hash_table,
-					 "a_bone_by_content_pattern");
+  if (info->a_bone_by_content_pattern == NULL)
+    info->a_bone_by_content_pattern
+      = ochusha_utils_get_attribute_string(hash_table,
+					   "a_bone_by_content_pattern");
 
   return;
 }
@@ -1413,7 +1422,7 @@ calculate_weight(OchushaBBSThread *thread, BBSThreadGUIInfo *info, int rank,
 
       if (ts_cell_handle_is_long(result))
 	weight = (int)ts_cell_handle_get_long_value(result);
-      g_object_unref(G_OBJECT(result));
+      OCHU_OBJECT_UNREF(G_OBJECT(result));
     }
   else
     {
@@ -1732,10 +1741,10 @@ update_threadlist_entry_style(OchushaApplication *application,
 	  visual_parameter.background_color
 	    = (int)ts_cell_handle_get_long_value(bg);
 
-	  g_object_unref(G_OBJECT(fg));
-	  g_object_unref(G_OBJECT(bg));
+	  OCHU_OBJECT_UNREF(G_OBJECT(fg));
+	  OCHU_OBJECT_UNREF(G_OBJECT(bg));
 	}
-      g_object_unref(G_OBJECT(result));
+      OCHU_OBJECT_UNREF(G_OBJECT(result));
     }
   else
     {
