@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.h,v 1.26 2004/01/11 02:02:19 fuyu Exp $
+ * $Id: bulletin_board_ui.h,v 1.27 2004/01/13 01:23:08 fuyu Exp $
  */
 
 #ifndef _BULLETIN_BOARD_UI_H_
@@ -91,6 +91,10 @@ typedef struct _BulletinBoardGUIInfo
 
   gboolean enable_filter;
 
+  /* ¼VirtualBoard */
+  gboolean use_static_threadlist;
+
+
   /* Ʊ */
   volatile gboolean is_busy;
   volatile gboolean redraw_required;
@@ -151,6 +155,9 @@ void go_to_the_first_response_of_current_thread(OchushaApplication *application)
 
 void bookmark_thread(OchushaBulletinBoard *board, OchushaBBSThread *thread,
 		     OchushaApplication *application);
+void bookmark_remove_thread(OchushaBulletinBoard *board,
+			    OchushaBBSThread *thread,
+			    OchushaApplication *application);
 
 #ifdef __cplusplus
 } // extern "C"
