@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.15 2003/12/30 15:51:01 fuyu Exp $
+ * $Id: main.c,v 1.16 2004/01/13 14:54:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -82,6 +82,10 @@ main(int argc, char *argv[])
   init_memory_trace();
 #endif
 
+#if TRACE_REFCOUNT
+  init_refcount_trace();
+#endif
+
 #ifdef REG_POSIX_ENCODING_UTF8
   reg_set_encoding(REG_POSIX_ENCODING_UTF8);
 #else	/* old style */
@@ -168,12 +172,12 @@ main(int argc, char *argv[])
     }
 
   /* Remove session related arguments */
-  real_argv = G_MALLOC(sizeof(char *) * real_argc);
+  real_argv = g_malloc(sizeof(char *) * real_argc);	/* ĤϳȤ */
   real_argc = 0;
   for (i = 0; i < argc; i++)
     {
       if (argv[i] != NULL)
-	real_argv[real_argc++] = G_STRDUP(argv[i]);
+	real_argv[real_argc++] = g_strdup(argv[i]);	/* ĤϳȤ */
     }
 
   application->argc = real_argc;
@@ -258,6 +262,11 @@ main(int argc, char *argv[])
 
   G_FREE(application->threadlist_view_contents);
   application->threadlist_view_contents = NULL;
+  if (application->thread_view_font_name != NULL)
+    {
+      G_FREE(application->thread_view_font_name);
+      application->thread_view_font_name = NULL;
+    }
   G_FREE(application->user_default_filter.rule);
   application->user_default_filter.rule = NULL;
   G_FREE(application->web_browser_template);
@@ -273,6 +282,30 @@ main(int argc, char *argv[])
   G_FREE(application->config.proxy_password);
   application->config.proxy_password = NULL;
 
+  if (application->bookmark_text != NULL)
+    {
+      G_FREE(application->bookmark_text);
+      application->bookmark_text = NULL;
+    }
+
+  if (application->a_bone_by_name_pattern != NULL)
+    {
+      G_FREE(application->a_bone_by_name_pattern);
+      application->a_bone_by_name_pattern = NULL;
+    }
+
+  if (application->a_bone_by_id_pattern != NULL)
+    {
+      G_FREE(application->a_bone_by_id_pattern);
+      application->a_bone_by_id_pattern = NULL;
+    }
+
+  if (application->a_bone_by_content_pattern != NULL)
+    {
+      G_FREE(application->a_bone_by_content_pattern);
+      application->a_bone_by_content_pattern = NULL;
+    }
+
   if (application->last_name != NULL)
     {
       G_FREE(application->last_name);
@@ -296,6 +329,10 @@ main(int argc, char *argv[])
   dump_pointers();
 #endif
 
+#if TRACE_REFCOUNT
+  dump_objects();
+#endif
+
   if (application->log_file != stderr)
     fclose(application->log_file);
 
