@@ -326,7 +326,48 @@ ochusha_marshal_VOID__OBJECT_BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,STRING,ENUM (marshal.list:15) */
+/* VOID:OBJECT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:15) */
+void
+ochusha_marshal_VOID__OBJECT_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
+                                                      GValue       *return_value,
+                                                      guint         n_param_values,
+                                                      const GValue *param_values,
+                                                      gpointer      invocation_hint,
+                                                      gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN_BOOLEAN_BOOLEAN) (gpointer     data1,
+                                                                     gpointer     arg_1,
+                                                                     gboolean     arg_2,
+                                                                     gboolean     arg_3,
+                                                                     gboolean     arg_4,
+                                                                     gpointer     data2);
+  register GMarshalFunc_VOID__OBJECT_BOOLEAN_BOOLEAN_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 5);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT_BOOLEAN_BOOLEAN_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            g_marshal_value_peek_boolean (param_values + 2),
+            g_marshal_value_peek_boolean (param_values + 3),
+            g_marshal_value_peek_boolean (param_values + 4),
+            data2);
+}
+
+/* VOID:OBJECT,OBJECT,STRING,ENUM (marshal.list:16) */
 void
 ochusha_marshal_VOID__OBJECT_OBJECT_STRING_ENUM (GClosure     *closure,
                                                  GValue       *return_value,
@@ -367,7 +408,7 @@ ochusha_marshal_VOID__OBJECT_OBJECT_STRING_ENUM (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:16) */
+/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:17) */
 void
 ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
                                                        GValue       *return_value,
@@ -408,7 +449,7 @@ ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* BOOLEAN:ENUM,INT (marshal.list:17) */
+/* BOOLEAN:ENUM,INT (marshal.list:18) */
 void
 ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                    GValue       *return_value,
@@ -449,7 +490,7 @@ ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (marshal.list:18) */
+/* BOOLEAN:OBJECT (marshal.list:19) */
 void
 ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                  GValue       *return_value,
@@ -488,7 +529,48 @@ ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:19) */
+/* BOOLEAN:OBJECT,OBJECT (marshal.list:20) */
+void
+ochusha_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT_OBJECT) (gpointer     data1,
+                                                           gpointer     arg_1,
+                                                           gpointer     arg_2,
+                                                           gpointer     data2);
+  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__OBJECT_OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_object (param_values + 1),
+                       g_marshal_value_peek_object (param_values + 2),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:21) */
 void
 ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
                                                GValue       *return_value,
@@ -531,7 +613,7 @@ ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,INT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:20) */
+/* BOOLEAN:STRING,INT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:22) */
 void
 ochusha_marshal_BOOLEAN__STRING_INT_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                              GValue       *return_value,
