@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.59 2004/01/11 22:35:17 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.60 2004/01/13 01:23:08 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -52,6 +52,8 @@
 #define OCHUSHA_SESSION_XML				"session.xml.gz"
 #define OCHUSHA_INIT_SCM				"ochusha-init.scm"
 
+#define OCHUSHA_CURRENT_CONFIG_VERSION					2
+
 #define OCHUSHA_DEFAULT_WIDTH						600
 #define OCHUSHA_DEFAULT_HEIGHT						400
 #define OCHUSHA_DEFAULT_BOARDLIST_WIDTH					150
@@ -129,6 +131,8 @@ typedef enum
 
 struct _OchushaApplication
 {
+  int config_version;
+
   GtkWindow *top_level;
   GtkBox *main_window;
 
@@ -177,9 +181,7 @@ struct _OchushaApplication
   /* İθǡ */
   OchushaBoardCategory *my_folder;
   OchushaBulletinBoard *favorites;
-#if 0
   OchushaBulletinBoard *all_threads;
-#endif
   OchushaBBSTable *table;
 
 
