@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.c,v 1.17 2004/01/11 03:03:58 fuyu Exp $
+ * $Id: paned_notebook.c,v 1.18 2004/01/13 14:54:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -472,7 +472,7 @@ paned_notebook_init(PanedNotebook *paned_notebook)
   paned_notebook->tab_policy = GTK_POLICY_AUTOMATIC;
   paned_notebook->always_show_contents_pane = FALSE;
 
-  OCHU_OBJECT_REF(G_OBJECT(paned_notebook->contents_pane));
+  g_object_ref(paned_notebook->contents_pane);
   g_signal_connect(G_OBJECT(paned_notebook->contents_pane),
 		   "destroy",
 		   G_CALLBACK(gtk_widget_destroyed),
@@ -544,7 +544,7 @@ paned_notebook_destroy(GtkObject *object)
 
   if (paned_notebook->contents_pane != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(paned_notebook->contents_pane));
+      g_object_unref(paned_notebook->contents_pane);
       paned_notebook->contents_pane = NULL;
     }
 
