@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: response_editor.c,v 1.6 2003/12/29 05:21:09 fuyu Exp $
+ * $Id: response_editor.c,v 1.9 2004/01/10 20:59:26 fuyu Exp $
  */
 
 #include "config.h"
@@ -139,8 +139,10 @@ response_editor_init(ResponseEditor *editor)
   scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
 				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#if 0	/* themeǤˤޤ٤ */
   gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled_window),
 				      GTK_SHADOW_ETCHED_IN);
+#endif
   gtk_widget_show(scrolled_window);
   gtk_box_pack_start(GTK_BOX(&editor->container),
 		     scrolled_window, TRUE, TRUE, 0);
@@ -265,6 +267,22 @@ response_editor_add_mail(ResponseEditor *editor, const gchar *mail)
 }
 
 
+void
+response_editor_clear_response(ResponseEditor *editor)
+{
+  GtkTextIter start_iter;
+  GtkTextIter end_iter;
+  GtkTextBuffer *buffer;
+
+  g_return_if_fail(IS_RESPONSE_EDITOR(editor));
+
+  buffer = gtk_text_view_get_buffer(editor->text_view);
+  gtk_text_buffer_get_start_iter(buffer, &start_iter);
+  gtk_text_buffer_get_end_iter(buffer, &end_iter);
+  gtk_text_buffer_delete(buffer, &start_iter, &end_iter);
+}
+
+
 gchar *
 response_editor_get_response(ResponseEditor *editor)
 {
