@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: thread_proxy.c,v 1.6 2004/01/10 17:23:38 fuyu Exp $
+ * $Id: thread_proxy.c,v 1.7 2004/01/13 14:54:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -182,7 +182,7 @@ thread_proxy_finalize(GObject *object)
 
   if (proxy->real_thread != NULL)
     {
-      g_object_unref(proxy->real_thread);
+      OCHU_OBJECT_UNREF(G_OBJECT(proxy->real_thread));
       proxy->real_thread = NULL;
     }
 
@@ -455,24 +455,27 @@ copy_info_from_real_thread(ThreadProxy *proxy)
   proxy_info->view_rank = info->view_rank;
   proxy_info->show_mailto_mode = info->show_mailto_mode;
 
-  if (info->last_name != NULL)
+  if (proxy_info->last_name == NULL && info->last_name != NULL)
     proxy_info->last_name = G_STRDUP(info->last_name);
-  if (info->last_mail != NULL)
+  if (proxy_info->last_mail == NULL && info->last_mail != NULL)
     proxy_info->last_mail = G_STRDUP(info->last_mail);
 
   proxy_info->thread_local_a_bone = info->thread_local_a_bone;
 
   proxy_info->a_bone_by_name = info->a_bone_by_name;
-  if (info->a_bone_by_name_pattern != NULL)
+  if (proxy_info->a_bone_by_name_pattern == NULL
+      && info->a_bone_by_name_pattern != NULL)
     proxy_info->a_bone_by_name_pattern
       = G_STRDUP(info->a_bone_by_name_pattern);
 
   proxy_info->a_bone_by_id = info->a_bone_by_id;
-  if (info->a_bone_by_id_pattern != NULL)
+  if (proxy_info->a_bone_by_id_pattern == NULL
+      && info->a_bone_by_id_pattern != NULL)
     proxy_info->a_bone_by_id_pattern = G_STRDUP(info->a_bone_by_id_pattern);
 
   proxy_info->a_bone_by_content = info->a_bone_by_content;
-  if (info->a_bone_by_content_pattern != NULL)
+  if (proxy_info->a_bone_by_content_pattern == NULL
+      && info->a_bone_by_content_pattern != NULL)
     proxy_info->a_bone_by_content_pattern
       = G_STRDUP(info->a_bone_by_content_pattern);
   proxy_info->bookmark_response_number = info->bookmark_response_number;
@@ -487,7 +490,7 @@ thread_proxy_new_with_thread(OchushaBBSThread *thread)
 				      "id", ochusha_bbs_thread_get_url(thread),
 				      "title", thread->title,
 				      NULL));
-  g_object_ref(G_OBJECT(thread));
+  OCHU_OBJECT_REF(G_OBJECT(thread));
   THREAD_PROXY(proxy)->real_thread = thread;
   copy_info_from_real_thread(THREAD_PROXY(proxy));
 
@@ -511,8 +514,8 @@ thread_proxy_set_real_thread(ThreadProxy *proxy, OchushaBBSThread *thread)
   g_return_if_fail(OCHUSHA_IS_BBS_THREAD(thread));
 
   if (proxy->real_thread != NULL)
-    g_object_unref(G_OBJECT(proxy->real_thread));
-  g_object_ref(G_OBJECT(thread));
+    OCHU_OBJECT_UNREF(G_OBJECT(proxy->real_thread));
+  OCHU_OBJECT_REF(G_OBJECT(thread));
   proxy->real_thread = thread;
   copy_info_from_real_thread(proxy);
 }
