@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_filter.c,v 1.12 2004/01/11 03:03:58 fuyu Exp $
+ * $Id: threadlist_filter.c,v 1.13 2004/01/13 14:54:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -1312,12 +1312,12 @@ threadlist_filter_setting_finalize(GObject *object)
 
   if (setting->all_rules_model != NULL)
     {
-      g_object_unref(setting->all_rules_model);
+      OCHU_OBJECT_UNREF(G_OBJECT(setting->all_rules_model));
       setting->all_rules_model = NULL;
     }
   if (setting->current_rules_model != NULL)
     {
-      g_object_unref(setting->current_rules_model);
+      OCHU_OBJECT_UNREF(G_OBJECT(setting->current_rules_model));
       setting->current_rules_model = NULL;
     }
 
