@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.32 2004/01/11 22:33:04 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.33 2004/01/13 01:23:08 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -273,6 +273,8 @@ void threadlist_view_update_thread(ThreadlistView *view,
 void threadlist_view_update_thread_visual(ThreadlistView *view,
 				OchushaBBSThread *thread,
 				ThreadlistEntryVisualParameter *parameter);
+void threadlist_view_remove_thread(ThreadlistView *view,
+				   OchushaBBSThread *thread);
 
 void threadlist_view_scroll_to_thread(ThreadlistView *view,
 				      OchushaBBSThread *thread);
