@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: virtual_board.c,v 1.9 2004/01/13 01:23:08 fuyu Exp $
+ * $Id: virtual_board.c,v 1.10 2004/01/13 14:54:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -447,7 +447,7 @@ internal_each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
   if (proxy->real_thread == NULL)
     {
       /* bookmark줿ĤξΤߤ */
-      g_object_ref(G_OBJECT(thread));
+      OCHU_OBJECT_REF(G_OBJECT(thread));
       proxy->real_thread = thread;
     }
 
