@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.8 2004/01/08 19:44:59 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.9 2004/01/11 22:29:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -411,7 +411,7 @@ ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
 				     const gchar *title_utf8,
 				     const OchushaBBSResponse *response)
 {
-#if 0
+#if 0	/* Ǥ̤ݡ */
   OchushaBoard2ch *board_2ch;
   char *tmp_string = NULL;
   char *title = NULL;
@@ -433,6 +433,7 @@ ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       break;
     default:
       return FALSE;	/* ̤ݡ */
@@ -493,6 +494,7 @@ ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
       query = g_strdup_printf("submit=%%90%%56%%8B%%4B%%83%%58%%83%%8C%%83%%62%%83%%68%%8D%%EC%%90%%AC&subject=%s&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&time=%ld", title, from, mail, message, bbs, time);
       break;
 
