@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.43 2004/01/09 21:17:50 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.44 2004/01/13 14:51:37 fuyu Exp $
  */
 
 #include "config.h"
@@ -2245,8 +2245,11 @@ ochusha_network_broker_read_from_url(OchushaNetworkBroker *broker,
       || mode == OCHUSHA_NETWORK_BROKER_CACHE_ONLY)
     {
       /* å夬ä餽򤽤Τޤ޻Ȥ */
-      int fd = ochusha_config_cache_open_file(broker->config,
-					      url, O_RDONLY);
+      int fd;
+      if (buffer != NULL && buffer->length > 0)
+	return buffer;
+
+      fd = ochusha_config_cache_open_file(broker->config, url, O_RDONLY);
       if (fd >= 0)
 	{
 	  WorkerJob *job = G_NEW0(WorkerJob, 1);
