@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_private.h,v 1.18 2004/01/11 02:13:35 fuyu Exp $
+ * $Id: ochusha_private.h,v 1.19 2004/01/13 14:52:49 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_PRIVATE_H_
@@ -32,6 +32,7 @@
 #include "config.h"
 
 #define TRACE_MEMORY_USAGE	0
+#define TRACE_REFCOUNT		0
 
 #define ENABLE_FAKE_ANCHOR	1
 #define ENABLE_SKIP_IME_NU	1
@@ -52,9 +53,6 @@
 #define DEBUG_POST		0
 #define DEBUG_POST_MOST		0
 
-#define DEBUG_REF_COUNT		0
-
-
 
 #include "utils.h"
 
@@ -82,7 +80,7 @@ extern "C" {
 
 #if TRACE_MEMORY_USAGE
 static inline gpointer
-trace_g_malloc(gulong size, char *file, int line)
+trace_g_malloc(gulong size, const char *file, int line)
 {
   char where[1024];
   gpointer result = g_malloc(size);
@@ -94,7 +92,7 @@ trace_g_malloc(gulong size, char *file, int line)
 #define G_MALLOC(size)		trace_g_malloc(size, __FILE__, __LINE__)
 
 static inline gpointer
-trace_g_malloc0(gulong size, char *file, int line)
+trace_g_malloc0(gulong size, const char *file, int line)
 {
   char where[1024];
   gpointer result = g_malloc0(size);
@@ -106,7 +104,7 @@ trace_g_malloc0(gulong size, char *file, int line)
 #define G_MALLOC0(size)		trace_g_malloc0(size, __FILE__, __LINE__)
 
 static inline gpointer
-trace_g_realloc(gpointer pointer, gulong size, char *file, int line)
+trace_g_realloc(gpointer pointer, gulong size, const char *file, int line)
 {
   char where[1024];
   gpointer result = g_realloc(pointer, size);
@@ -122,7 +120,7 @@ trace_g_realloc(gpointer pointer, gulong size, char *file, int line)
 #define G_NEW0(struct_type, n_structs)	((struct_type *)trace_g_malloc0(((gsize) sizeof (struct_type)) * ((gsize) (n_structs)), __FILE__, __LINE__))
 
 static inline gchar *
-trace_g_strdup(const gchar *string, char *file, int line)
+trace_g_strdup(const gchar *string, const char *file, int line)
 {
   char where[1024];
   gpointer result = g_strdup(string);
@@ -135,7 +133,7 @@ trace_g_strdup(const gchar *string, char *file, int line)
 
 
 static inline gchar *
-trace_g_strndup(const gchar *string, int len, char *file, int line)
+trace_g_strndup(const gchar *string, int len, const char *file, int line)
 {
   char where[1024];
   gpointer result = g_strndup(string, len);
@@ -148,7 +146,7 @@ trace_g_strndup(const gchar *string, int len, char *file, int line)
 
 
 static inline gpointer
-trace_g_memdup(gconst pointer, int len, char *file, int line)
+trace_g_memdup(gconstpointer pointer, int len, const char *file, int line)
 {
   char where[1024];
   gpointer result = g_memdup(pointer, len);
@@ -161,7 +159,7 @@ trace_g_memdup(gconst pointer, int len, char *file, int line)
 
 
 static inline void
-trace_g_free(gpointer pointer, char *file, int line)
+trace_g_free(gpointer pointer, const char *file, int line)
 {
   char where[1024];
   snprintf(where, 1024, "g_free(%p) at %s, line %d",
@@ -184,30 +182,16 @@ trace_g_free(gpointer pointer, char *file, int line)
 #endif
 
 
-#if DEBUG_REF_COUNT
-#define OCHU_OBJECT_REF(obj)						\
-  do									\
-    {									\
-      g_object_ref(obj);						\
-      fprintf(stderr,							\
-	      "g_object_ref(%p) at %s, line %d: ref_count=%d\n",	\
-	      obj, __FILE__, __LINE__, (obj)->ref_count);		\
-    } while (0)
-
-#define OCHU_OBJECT_UNREF(obj)						\
-  do									\
-    {									\
-      fprintf(stderr,							\
-	      "g_object_unref(%p) at %s, line %d: ref_count=%d\n",	\
-	      obj, __FILE__, __LINE__, (obj)->ref_count);		\
-      g_object_unref(obj);						\
-    } while (0)
-
+#if TRACE_REFCOUNT
+#define OCHU_OBJECT_REGISTER(obj)	trace_register_g_object(obj, __FILE__, __LINE__)
+#define OCHU_OBJECT_REF(obj)	trace_g_object_ref(obj, __FILE__, __LINE__)
+#define OCHU_OBJECT_UNREF(obj)	trace_g_object_unref(obj, __FILE__, __LINE__)
 #define OCHU_OBJECT_REF_FUNC	ochu_object_ref
 #define OCHU_OBJECT_UNREF_FUNC	ochu_object_unref
   
 #else
 
+#define OCHU_OBJECT_REGISTER(obj)
 #define OCHU_OBJECT_REF(obj)	g_object_ref(obj)
 #define OCHU_OBJECT_UNREF(obj)	g_object_unref(obj)
 #define OCHU_OBJECT_REF_FUNC	g_object_ref
