@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.53 2004/01/11 22:29:14 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.54 2004/01/13 14:49:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -859,8 +859,8 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	int interval = ANALYSIS_INTERVAL;
 
 #if DEBUG_DAT_MOST
-	fprintf(stderr, "1: ochusha_thread_2ch.c: length=%d\n",
-		buffer->length);
+	fprintf(stderr, "1: ochusha_thread_2ch.c: offset=%d, rest_of_data=%d, length=%d\n",
+		offset, rest_of_data, buffer->length);
 #endif
 	while (rest_of_data > 0
 	       && (rest_of_responses > 0 || rest_of_responses == -1)
@@ -1050,8 +1050,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
       }
 
   terminated:
-    if (number == MAX_RESPONSE)
-      thread->number_of_responses_read = i;
+    thread->number_of_responses_read = i;
   }
   ochusha_async_buffer_unlock(buffer);
 
