@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.23 2004/01/08 19:44:59 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.24 2004/01/13 14:49:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -730,8 +730,10 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	    goto retry_analysis;
 	  }
       }
+
+  terminated:
+    thread->number_of_responses_read = i;
   }
- terminated:
   ochusha_async_buffer_unlock(buffer);
 
   if (status->last_modified != NULL)
