@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.c,v 1.18 2004/01/09 21:16:06 fuyu Exp $
+ * $Id: utils.c,v 1.19 2004/01/13 14:52:49 fuyu Exp $
  */
 
 #define OCHUSHA_UTILS_IMPLEMENTATION
@@ -1627,28 +1627,12 @@ cp932_to_utf8_helper(const char **inbuf, size_t *inbytesleft,
 }
 
 
-#if DEBUG_REF_COUNT
-void
-ochu_object_ref(GObject *object)
-{
-  OCHU_OBJECT_REF(object);
-}
-
-
-void
-ochu_object_unref(GObject *object)
-{
-  OCHU_OBJECT_UNREF(object);
-}
-#endif
-
-
 #if TRACE_MEMORY_USAGE
 /*
  * ꡼åϢ
  */
-pthread_mutex_t memory_trace_lock;
-GHashTable *memory_trace;
+static pthread_mutex_t memory_trace_lock;
+static GHashTable *memory_trace;
 
 
 #define MEMORY_TRACE_LOCK				\
@@ -1716,7 +1700,10 @@ unregister_pointer(gpointer pointer, const char *where)
 static void
 print_pointer_info(gpointer key, gpointer value, gpointer user_data)
 {
-  fprintf(stderr, "%p: %s\n", key, (char *)value);
+  if (strstr((const char *)value, "g_str") != NULL)
+    fprintf(stderr, "%p \"%s\": %s\n", key, (char *)key, (char *)value);
+  else
+    fprintf(stderr, "%p: %s\n", key, (char *)value);
 }
 
 
@@ -1730,3 +1717,185 @@ dump_pointers()
   MEMORY_TRACE_UNLOCK;
 }
 #endif
+
+
+#if TRACE_REFCOUNT
+static pthread_mutex_t refcount_trace_lock;
+static GHashTable *refcount_trace;
+static GSList *consistent_object_list;
+
+
+#define REFCOUNT_TRACE_LOCK				\
+  if (pthread_mutex_lock(&refcount_trace_lock) != 0)	\
+    {							\
+      fprintf(stderr, "Couldn't lock a mutex.\n");	\
+      abort();						\
+    }
+
+#define REFCOUNT_TRACE_UNLOCK				\
+  if (pthread_mutex_unlock(&refcount_trace_lock) != 0)	\
+    {							\
+      fprintf(stderr, "Couldn't unlock a mutex.\n");	\
+      abort();						\
+    }
+
+
+static void
+delete_refcount_history(GSList *history)
+{
+  g_slist_foreach(history, (GFunc)g_free, NULL);
+  g_slist_free(history);
+}
+
+
+void
+init_refcount_trace(void)
+{
+  if (pthread_mutex_init(&memory_trace_lock, NULL) != 0)
+    {
+      fprintf(stderr, "Couldn't init a mutex.\n");
+      abort();
+    }
+
+  refcount_trace = g_hash_table_new(g_direct_hash, g_direct_equal);
+  consistent_object_list = NULL;
+}
+
+
+void
+trace_register_g_object(GObject *object, const char *file, int line)
+{
+  GSList *previous;
+  char where[1024];
+  snprintf(where, 1024, "register_g_object(%p) at %s, line %d: ref_count=%d",
+	   object, file, line, object->ref_count);
+  REFCOUNT_TRACE_LOCK
+  {
+    previous = g_hash_table_lookup(refcount_trace, object);
+    if (previous != NULL)
+      {
+	if (g_slist_find(consistent_object_list, object) != NULL)
+	  {
+	    consistent_object_list = g_slist_remove(consistent_object_list,
+						    object);
+	    delete_refcount_history(previous);
+	    previous = NULL;
+	  }
+      }
+    g_hash_table_insert(refcount_trace, object,
+			g_slist_append(previous, g_strdup(where)));
+  }
+  REFCOUNT_TRACE_UNLOCK;
+}
+
+
+void
+trace_g_object_ref(GObject *object, const char *file, int line)
+{
+  GSList *history;
+  char where[1024];
+  snprintf(where, 1024, "g_object_ref(%p) at %s, line %d: ref_count=%d",
+	   object, file, line, object->ref_count);
+  REFCOUNT_TRACE_LOCK
+  {
+    history = g_hash_table_lookup(refcount_trace, object);
+    g_hash_table_insert(refcount_trace, object,
+			g_slist_append(history, g_strdup(where)));
+  }
+  REFCOUNT_TRACE_UNLOCK;
+  g_object_ref(object);
+}
+
+
+void
+trace_g_object_unref(GObject *object, const char *file, int line)
+{
+  GSList *history;
+  char where[1024];
+  snprintf(where, 1024, "g_object_unref(%p) at %s, line %d: ref_count=%d",
+	   object, file, line, object->ref_count);
+  REFCOUNT_TRACE_LOCK
+  {
+    history = g_hash_table_lookup(refcount_trace, object);
+    g_hash_table_insert(refcount_trace, object,
+			g_slist_append(history, g_strdup(where)));
+    if (object->ref_count == 1)
+      consistent_object_list = g_slist_append(consistent_object_list, object);
+    else if (object->ref_count == 0)
+      consistent_object_list = g_slist_remove(consistent_object_list, object);
+  }
+  REFCOUNT_TRACE_UNLOCK;
+  if (object->ref_count > 0 && object->ref_count < 100)
+    g_object_unref(object);
+}
+
+
+static void
+print_history(const char *where)
+{
+  fprintf(stderr, "%s\n", where);
+}
+
+
+static void
+remove_consistent_object(gpointer object)
+{
+  GSList *history = g_hash_table_lookup(refcount_trace, object);
+#if 0
+  fprintf(stderr, "*** Consistent object %p\n", object);
+  g_slist_foreach(history, (GFunc)print_history, NULL);
+  fprintf(stderr, "******\n\n");
+#endif
+  delete_refcount_history(history);
+  g_hash_table_remove(refcount_trace, object);
+}
+
+
+static void
+print_refcount_info(GObject *object, GSList *history, gpointer unused)
+{
+  fprintf(stderr, "*** Inconsistent object %p\n", object);
+  g_slist_foreach(history, (GFunc)print_history, NULL);
+  fprintf(stderr, "******\n\n");
+  delete_refcount_history(history);
+}
+
+
+void
+dump_objects(void)
+{
+  REFCOUNT_TRACE_LOCK
+  {
+    g_slist_foreach(consistent_object_list, remove_consistent_object, NULL);
+    g_hash_table_foreach(refcount_trace, (GHFunc)print_refcount_info, NULL);
+  }
+  REFCOUNT_TRACE_UNLOCK;
+}
+
+
+static void
+output_warning(GObject *object)
+{
+  fprintf(stderr, "%p seems not to be a valid pointer to GObject\n", object);
+}
+
+
+void
+ochu_object_ref(GObject *object)
+{
+  if (object->ref_count >= 100)
+    output_warning(object);
+  OCHU_OBJECT_REF(object);
+}
+
+
+void
+ochu_object_unref(GObject *object)
+{
+  if (object->ref_count < 1 || object->ref_count >= 100)
+    output_warning(object);
+  OCHU_OBJECT_UNREF(object);
+}
+#endif
+
+
